@@ -18,6 +18,7 @@ from .signals import (
     device_group_changed,
     device_name_changed,
     vpn_peers_changed,
+    vpn_server_modified,
 )
 
 # ensure Device.hardware_id field is not flagged as unique
@@ -211,6 +212,7 @@ class ConfigConfig(AppConfig):
             device_cache_invalidation_handler,
             devicegroup_change_handler,
             devicegroup_delete_handler,
+            vpn_server_change_handler,
         )
 
         post_save.connect(
@@ -252,6 +254,11 @@ class ConfigConfig(AppConfig):
             sender=self.device_model,
             dispatch_uid='device.invalidate_cache',
         )
+        vpn_server_modified.connect(
+            vpn_server_change_handler,
+            sender=self.vpn_model,
+            dispatch_uid='vpn.invalidate_checksum_cache',
+        )
 
     def register_dashboard_charts(self):
         register_dashboard_chart(
