@@ -78,3 +78,24 @@ def assign_devicegroup_permissions_to_groups(apps, schema_editor):
         )
         admin.permissions.add(permission.pk)
         operator.permissions.add(permission.pk)
+
+
+def assign_organization_config_settings_permissions_to_groups(apps, schema_editor):
+    create_default_permissions(apps, schema_editor)
+    operator_operations = ['view']
+    admin_operations = operator_operations + ['change']
+    Group = get_swapped_model(apps, 'openwisp_users', 'Group')
+    try:
+        admin = Group.objects.get(name='Administrator')
+        operator = Group.objects.get(name='Operator')
+    # consider failures custom cases
+    # that do not have to be dealt with
+    except Group.DoesNotExist:
+        return
+    for operation in admin_operations:
+        permission = Permission.objects.get(
+            codename='{}_{}'.format(operation, 'organizationconfigsettings')
+        )
+        if operation in operator_operations:
+            operator.permissions.add(permission.pk)
+        admin.permissions.add(permission.pk)
